@@ -24,8 +24,13 @@ def send_log(alert_id, context, message=None):
     base_url = __get_base_url(context['env'])
     req_url = '{}/alerting/log/{}'.format(base_url, alert_id)
 
+    if traceback.format_exc() == 'NoneType: None\n':
+        traceback_log = ''
+    else:
+        traceback_log = traceback.format_exc()
+
     req_body = {
-        "traceback_log": traceback.format_exc(),
+        "traceback_log": traceback_log,
         "context": context,
         "message": __set_message(message)}
 
